@@ -4,13 +4,13 @@
 ### code chunk number 1: expands.Rnw:43-52
 ###################################################
 library(expands)
-##loading mutations
+##load mutations:
 data(snv);
-## using only a subset of all mutations (to reduce time required to run this example)
-set.seed(6); idx=sample(1:nrow(snv), 130, replace=FALSE); snv=snv[idx,];
-##loading copy number segments
+## use only a subset of mutations (to reduce time required to run example):
+set.seed(6); idx=sample(1:nrow(snv), 80, replace=FALSE); snv=snv[idx,];
+##load copy number segments:
 data(cbs);
-##assigning copy numbers to point mutations
+##assign copy numbers to point mutations:
 dm=assignQuantityToMutation(snv,cbs,"CN_Estimate");
 
 
@@ -18,7 +18,7 @@ dm=assignQuantityToMutation(snv,cbs,"CN_Estimate");
 ### code chunk number 2: expands.Rnw:57-62
 ###################################################
 ##parameters
-max_PM=6; maxScore=1.25; precision=0.018;
+max_PM=6; maxScore=2; precision=0.018;
 plotF=1; 
 ##the name of the sample
 snvF="TCGA-06-0152-01";
@@ -27,7 +27,7 @@ snvF="TCGA-06-0152-01";
 ###################################################
 ### code chunk number 3: expands.Rnw:68-70
 ###################################################
-##compute the cell frequency probability distribution for each mutation
+##calculate cell frequency probability distribution for each mutation
 cfd=computeCellFrequencyDistributions(dm, max_PM, precision)
 
 
@@ -54,14 +54,14 @@ print(SPs)
 ###################################################
 ### code chunk number 7: expands.Rnw:91-93
 ###################################################
-##assign mutations to subpopulations
+##assign mutations to subpopulations:
 aM= assignMutations( dm, SPs)
 
 
 ###################################################
 ### code chunk number 8: expands.Rnw:103-104
 ###################################################
-plotSPs(aM$dm, snvF,cex=1)
+o=plotSPs(aM$dm, snvF,cex=1)
 
 
 ###################################################
@@ -75,13 +75,13 @@ aQ=assignQuantityToSP(cbs, aM$dm)
 ### code chunk number 10: expands.Rnw:120-122
 ###################################################
 ##building phylogeny
-spPhylo=buildPhylo(aQ$ploidy,snvF)
+spPhylo=buildPhylo(aQ,snvF,add = NULL)
 
 
 ###################################################
 ### code chunk number 11: expands.Rnw:127-128
 ###################################################
-plot(spPhylo$tree,cex=2.5)
+plot(spPhylo$tree,cex=1.5,type = "c")
 
 
 ###################################################
@@ -101,7 +101,7 @@ sps=as.list(paste(patient, samples,'.sps',sep=""));
 ### code chunk number 13: expands.Rnw:150-161
 ###################################################
 sampleGroup=list(cbs=cbs,sps=sps,labels=samples)
-tr=buildMultiSamplePhylo(sampleGroup,output,ambigSg = F, plotF=0);
+tr=buildMultiSamplePhylo(sampleGroup,output,ambig = F, plotF=0);
 ##Tree tip color labels according to sample origin of SPs:
 jet <- colorRampPalette(c("#00007F", "blue", "#007FFF",
             "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))
@@ -116,6 +116,6 @@ for (i in 1: length(sampleGroup$labels) ) {
 ###################################################
 ### code chunk number 14: expands.Rnw:166-167
 ###################################################
-plot(tr, tip.col = colors, cex = 1.6, type = "u")
+plot(tr, tip.col = colors, cex = 0.9, type = "u")
 
 
